/**
 * The Bread class represents a meal that can be consumed by the kobold,
 * which increases its statuses.
 */
function Bread() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Bread";
    var itemDescription = "A thick loaf of bread.";
    var baseValue = 4;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You bring the bread up to your lips, and [b]tear[/b] into it,
                            ripping off over half of the loaf in a single bite.
                            While exceedingly dry, and lacking flavored condiments,
                            the staple food for many species across the world still tastes better than what you [i]usually[/i] eat.
                            As you munch on the food, you ponder the immense gap between the average living conditions of humans and kobolds.
                        [/p]
                        [p]
                            You gobble down the rest of the bread, crumbs falling to the ground en masse.
                            It may not be very [i]satisfying[/i] to eat, but it still manages to fill you up rather nicely.
                            By the time it's all gone, you feel slightly energized, all though not nearly as much as a [b]full[/b] meal would have left you.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.BREAD;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(3, "Ate bread");
        global.kobold.status.mental.increase(3, "Ate bread");
        global.kobold.status.stamina.increase(3, "Ate bread");
        global.kobold.status.exertion.decrease(3, "Ate bread");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +3), 
            new Change("Food", "Sanity", +3),
            new Change("Food", "Stamina", +3),
            new Change("Food", "Sexual exhaustion", -3, true)
        ]);
        global.ui.showFullscreenPopup(contents);
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
