/**
 * The RejuvinationPotion class represents a potion that can be consumed by the kobold,
 * which increases its statuses.
 */
function RejuvenationPotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Rejuvenation Potion";
    var itemDescription = "A medium-sized potion. White liquid sloshes within. The label on the side says that it'll make you feel better, whatever that means.";
    var baseValue = 30;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                            The white fluid within smells creamy, like milk.
                            Freshly squeezed milk.
                            Emboldened by the fragrance, you lower the vial to your slightly parted lips, before tipping it backwards, 
                            along with your head, letting the contents flood into your mouth.
                        [/p]
                        [p]
                            The fluid tastes [b]exactly[/b] the way it smells, just like milk!
                            The consistency matches as well.
                            The only thing discerning it from regular cow-produce is the intense,
                            [b]wholesome[/b] feeling flooding your body the moment the stuff disappears down your throat.
                        [/p]
                        [p]
                            You chug down the entire small bottle's worth of the beneficial liquid,
                            savoring the taste and basking in the regenerative properties of the milk-like substance.
                            Your mind clears, various minor scrapes and cuts slowly vanish,
                            you feel [b]energized[/b] and ready to take on the entire world.
                        [/p]
                        [p]
                            As the last few droplets of the rejuvenation potion disappear down your throat,
                            you are left thoroughly revitalized, prepared for whatever challenges may lie before you.
                            As the reinvigorating sensation fades, you are left lusting for [b]more[/b].
                            You get the feeling this altered milk is slightly [i]addictive[/i].
                            Perhaps you should take care [b]not[/b] to consume [i]too much[/i] of it.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.REJUVINATION_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 200px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(20, "Rejuvenation potion");
        global.kobold.status.mental.increase(20, "Rejuvenation potion");
        global.kobold.status.stamina.increase(20, "Rejuvenation potion");
        global.kobold.status.exertion.decrease(20, "Rejuvenation potion");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Potion", "Health", +20), 
            new Change("Potion", "Sanity", +20),
            new Change("Potion", "Stamina", +20),
            new Change("Potion", "Sexual exhaustion", -20, true)
        ]);
        global.ui.showFullscreenPopup(contents);
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
