/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementCooperate(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementMouthChoice.COOPERATE;
    var reqController = ctrl.mouth;
    var subController = ctrl.postMouth;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementTightness(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var further = ctrl.name.get() === CaravanConfinementNameChoice.STATE;
        var toReturn = `[p]
                            Not wanting to anger your captors, you open your mouth wide.
                            The human seems pleased with your decision to cooperate, his stern visage somewhat relaxing${further ? `further` : ``}.
                            "[color=brown]'Atta ${male ? "boy" : "girl"}.[/color]" he says, lowering his head to better gaze into your maw,
                            inspecting your gums, your teeth and your tongue, internally grading you like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Finished with his inspection, the man removes his fingers from your muzzle.
                            "[color=brown]No apparent diseases.
                            Mouth seems clean enough.
                            Teeth might need some [b]filing[/b], but that's not [i]our[/i] job.[/color]"
                        [/p]
                        [p]
                            Your maw graded, the caravan master runs his eyes along the rest your naked frame, examining you from top to bottom.
                            "[color=brown]Some small cuts and bruises.
                            Nothing major.
                            I wouldn't call it [i]pristine[/i] condition, but good enough for sellin'.
                            Looks like we might not have to roast you over the open fire after all, kobold.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
