/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseFollowRun(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You silently close the door behind you, and turn around to face what you hope will be an easy getaway.
                            Instead, you are greeted with the sight of a broad-postured, scythe-wielding human, presumably the farmer who lives here.
                            He glares down at you.
                            You stare back at him.
                            For a moment, neither of you move.
                            He grips his scythe with both hands.
                            You can almost [b]feel[/b] the tension in the air.
                        [/p]
                        [p]
                            [big]"[color=dred][b]Thief![/b][/color]"[/big]
                            the man bellows out in a deep, bass voice, breaking the small stalemate between the two of you, rallying comrades to his aid.
                            The human advances upon you.
                            He attacks you with an overhead scythe-swipe, which you narrowly manage to avoid.
                            The blade of his weapon ends up being stuck in the wooden backdoor, giving you just enough time to run past him, into the adjacent potato field.
                            The farmer struggles to recover his lethal tool, although not for long.
                            He gives chase, wildly swings his scythe at you, only [b]barely[/b] missing your tail with every cut.
                            To make matters worse, he's [b]gaining[/b] on you.
                        [/p]
                        [p]
                            Being almost twice your size, he can take far bigger steps, thus traversing the rough farmland with greater ease.
                            Halfway across the field, you can almost [b]feel[/b] his weapon cutting through the air, nearly slicing off the very tip of your hind appendage.
                            Right as he was about to land a definitive strike, the clumsy human trips over a pile of dirt, landing face-first on the hard, tilled ground.
                            You glance back at him just to gloat, but the sight of a veritable [b]mob[/b] of armed farmers rushing out of the hamlet towards you 
                            inspires you to keep running instead of rubbing the man's defeat in his face.
                        [/p]
                        [p]
                            For the second time in recent history, you find yourself running from a group of angry peasants.
                            This time, luckily, you have somewhat of a headstart.
                            That, and the farmers chasing you seem more interested in helping the man that originally chased you off to his feet,
                            rather than pursuing you as you escape through a sparse set of trees.
                            Still, you keep running for quite a while, all the way back to the eastern road to Varanar.
                        [/p]
                        [p]
                            Confident that you've lost your pursuers, you take a moment to catch your breath.
                            That was close.
                            If that stupid farmer hadn't tripped, you'd be minced meat by now.
                            Luckily, you made it out alive, with some yummy sandwiches to show for it.
                            The housewife was annoying to deal with, and you could have wrung her neck in frustration when she closed the door to the den behind her,
                            but in the end, you feel like you at at least got something out of this entire ordeal.
                            It may not be much, but it's more than nothing.
                            And more than nothing is all you need to survive in Varanar.
                            [small]Or so you hope.[/small]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.follow.continued()) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.runChange();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.follow.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
