/**
 * Controller for the Well scene.
 * @param {string} sceneId The id of the scene.
 */
function HamletWellController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = true;
    this.nextSceneName = "UndergroundCave";
    this.nextFolderName = "HamletDay2";
    this.varanarSceneName = "NightTwo";
    this.varanarFolderName = "Varanar";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChoiceController(id, "arrival");

    this.rope = new ChangeController(id, "rope", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(15, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(17, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -3),
            new Change("Squished by debris", "Health", -5),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Climbing", "Stamina", -3),
            new Change("Screaming", "Stamina", -2),
            new Change("Pushing rock off", "Stamina", -4),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        changes.concat(
                [new Change("Used rope", global.kobold.inventory.createItemWithTooltip(new Rope(), true), -1),
                    new Change("Recovered rope", global.kobold.inventory.createItemWithTooltip(new Rope(), true), +1)]);

        return global.ui.change.buildNotification(changes);
    });

    this.walk = new ChangeController(id, "walk", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(10, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.waterFail = new ChangeController(id, "waterFail", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(8, "Stuck in the well");
        global.kobold.status.stamina.decrease(12, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Tugging", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.waterSucceed = new ChangeController(id, "waterSucceed", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(18, "Nearly drowning");
        global.kobold.status.mental.decrease(3, "Stuck in the well");
        global.kobold.status.stamina.decrease(12, "Almost drowning");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Bonked head", "Health", -7),
            new Change("Nearly drowned", "Health", -7),
            new Change("Drew water", "Sanity", +5),
            new Change("Fell in well", "Sanity", -6),
            new Change("Nearly drowned", "Sanity", -5),
            new Change("Survived", "Sanity", +3),
            new Change("Tugging", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Drowning", "Stamina", -8)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.climbFail = new ChangeController(id, "climbFail", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.physical.decrease(7, "Falling into the well");
        global.kobold.status.mental.decrease(3, "Stuck in the well");
        global.kobold.status.stamina.decrease(6, "Falling into the well");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Fell into water", "Health", -4),
            new Change("Water in lungs", "Health", -3),
            new Change("Fell in well", "Sanity", -6),
            new Change("Survived", "Sanity", +3),
            new Change("Climbing", "Stamina", -2),
            new Change("Screaming", "Stamina", -2),
            new Change("Coughing", "Stamina", -2)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.climbSucceed = new ChangeController(id, "climbSucceed", function () {
        global.kobold.inventory.equipment.cleanAll();
        global.kobold.status.mental.increase(7, "Climbing into the well");
        global.kobold.status.stamina.decrease(12, "Climbing into the well");
        if (that.misc.exertion()) {
            global.kobold.status.exertion.decrease(5, "Cold water");
        }
    }, function () {
        var changes = [
            new Change("Climbed down", "Sanity", +10),
            new Change("Stuck", "Sanity", -3),
            new Change("Climbing", "Stamina", -12)
        ];
        if (that.misc.exertion()) {
            changes.push(new Change("Cold water", "Sexual exhaustion", -5, true));
        }
        return global.ui.change.buildNotification(changes);
    });

    this.down = new ChoiceController(id, "down");

    this.pants = new ChangeController(id, "pants", function () {
        that.misc.pants();
        global.kobold.status.mental.increase(5, "Finding gold in the well");
        global.kobold.status.stamina.decrease(6, "Diving");
        global.kobold.inventory.coins = global.kobold.inventory.coins + 37;
        global.kobold.inventory.equipment.strip(SlotEnum.PANTS);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Lost pants", "Sanity", -2),
            new Change("Found gold", "Sanity", +7),
            new Change("Diving", "Stamina", -6),
            new Change("Found gold", "Coins", +37),
            new Change("Ripped pants", global.kobold.inventory.createItemWithTooltip(that.misc.pants(), true), -1)
        ]);
    });

    this.scrape = new ChangeController(id, "scrape", function () {
        global.kobold.status.physical.decrease(15, "Scraped leg");
        global.kobold.status.mental.decrease(10, "Pain");
        global.kobold.status.stamina.decrease(3, "Diving");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Scraped", "Health", -15),
            new Change("Pain", "Sanity", -10),
            new Change("Diving", "Stamina", -3)
        ]);
    });

    this.climbUp = new ChangeController(id, "climbUp", function () {
        global.kobold.status.mental.decrease(5, "Almost fell down");
        global.kobold.status.stamina.decrease(15, "Climbing up");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Almost fell", "Sanity", -5),
            new Change("Climbing up", "Stamina", -15)
        ]);
    });

    this.climbUpRelent = new ChangeController(id, "climbUpRelent", function () {
        global.kobold.status.mental.increase(4, "Still stuck");
        global.kobold.status.stamina.decrease(8, "Climbing down");
        global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stopped before getting hurt", "Sanity", +6),
            new Change("Still stuck", "Sanity", -2),
            new Change("Climbing down", "Stamina", -8),
            new Change("Good workout", "Agility", +1)
        ]);
    });

    this.climbUpFail = new ChangeController(id, "climbUpFail", function () {
        global.kobold.status.physical.decrease(25, "Hit head against wall");
        global.kobold.status.mental.decrease(16, "Seriously hurt");
        global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hit head", "Health", -15),
            new Change("Knocked unconscious", "Health", -10),
            new Change("Fell down", "Sanity", -6),
            new Change("Seriously hurt", "Sanity", -10),
            new Change("Hit head", "Intelligence", -1)
        ]);
    });

    this.climbUpSucceed = new ChangeController(id, "climbUpSucceed", function () {
        global.kobold.status.physical.decrease(5, "Overexertion");
        global.kobold.status.mental.increase(20, "Escaped the well");
        global.kobold.status.stamina.decrease(20, "Intensive climbing");
        global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Overexertion", "Health", -5),
            new Change("Impressed self", "Sanity", +10),
            new Change("Escaped the well", "Sanity", +10),
            new Change("Intensive climbing", "Stamina", -20),
            new Change("Pushed your limits", "Endurance", +1)
        ]);
    });

    this.help = new ChangeController(id, "help", function () {
        global.kobold.status.mental.increase(2, "Help?");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Potential help", "Sanity", +2)
        ]);
    });

    this.helpScold = new ChangeController(id, "helpScold", function () {
        global.kobold.status.mental.decrease(19, "Rude children");
        global.kobold.stats.decreaseStat(StatsEnum.CHARISMA, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Peed on (kind of)", "Sanity", -10),
            new Change("Laughed at", "Sanity", -2),
            new Change("Frustration", "Sanity", -7),
            new Change("Botched negotiations", "Charisma", -1)
        ]);
    });

    this.helpBegFail = new ChangeController(id, "helpBegFail", function () {
        global.kobold.status.mental.decrease(13, "Mean kids");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Insulted", "Sanity", -1),
            new Change("Laughed at", "Sanity", -2),
            new Change("Left to die", "Sanity", -10)
        ]);
    });

    this.helpBegSucceed = new ChangeController(id, "helpBegSucceed", function () {
        global.kobold.status.mental.increase(20, "Shown kindness by a stranger");
        global.kobold.status.stamina.decrease(10, "Climbed out of the well");
        global.kobold.stats.increaseStat(StatsEnum.LUCK, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped", "Sanity", +20),
            new Change("Climbing", "Stamina", +10),
            new Change("Saved by a stranger", "Luck", +1)
        ]);
    });

    this.preContinue = new ChoiceController(id, "preContinue");

    this.bgm = new AudioController(id, "res/audio/effects/waterdrip.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

var HamletWellFallChoice = {
    SWIM: 1,
    CLIMB: 2,
    HELP: 3
};
