/**
 * Free section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopFree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "freeContinueButton";

    var next = new SekiWorkshopCenter(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After about a minute of waiting, you begin to get a bit impatient.
                            You ring the bell a few more times, until you finally get a response in the form of a raspy,
                            bass shout coming from the darkness on the far end of the counter:
                            "[color=brown]Hold your horses!
                            Settle down!
                            I'm on my way!
                            Can't an old man get a minute to finish grinding his herbs?!
                            You youngsters are always so [b]restive[/b]![/color]"
                        [/p]
                        [p]
                            Loudly grumbling, the elderly owl emerges from the shadows, stepping into the dim candlelight,
                            which illuminates his once-brown, but now pale grey feathers.
                            Readjusting the heavy, thick spectacles atop his beak,
                            the angry frown on the bird's face changes to a happy,
                            heartfelt smile as he realizes the tiny little thing that interrupted his machinations was none other but, well, [b]you[/b].
                        [/p]
                        [p]
                            "[color=brown]Ahhh!
                            My favorite customer!
                            Uhhh...[/color]"
                            The avian brings his feathery hand towards his forehead, wiping his brow as he visibly tries his very hardest to recall your name.
                            You know he didn't forget you.
                            His old mind just can't remember things quite as well as it used to.
                            You understand.
                            Returning a smile, you coyly hint that your name is ${ctrl.name()}.
                        [/p]
                        [p]
                            "[color=brown]Yes, yes!
                            ${ctrl.name()}!
                            I knew that!
                            I was just [b]catching my breath[/b] from walking all the way over here.[/color]"
                            Silly old geezer.
                            "[color=brown]Let me take a good look at you.[/color]"
                            He continues, leaning forwards over the counter, gazing down at you with his large owl eyes.
                        [/p]
                        `;
        if (ctrl.health() < 80) {
            toReturn += `[p] 
                            "[color=brown]You look like you've seen better days!
                            Who'd you get in a tussle with this time, eh?
                            It's probably best if you [b]don't[/b] tell me.
                            If they can beat up a fierce youngling like yourself, an old geezer like me wouldn't stand much of a chance.
                            Twenty years ago, I'd have shown those ruffians what-for, let me tell you![/color]"
                        [/p]`;
        } else {
            toReturn += `[p] 
                            "[color=brown]You look fit as ever!
                            Taking good care of yourself, eh?
                            'Atta ${ctrl.gender() === GenderEnum.MALE ? "boy" : "girl"}.
                            It'd pain an old man's heart to see a pretty little snout like yours get hurt.
                            Do me a favor and keep yourself out of harm's way, won't you?
                            Not for your sake, but for mine.[/color]"
                        [/p]`;
        }

        toReturn += `   [p] 
                            Then, Seki begins to reminisce, as he always does when you come to visit him.
                            "[color=brown]When I was your age, I was out explorin' the world.
                            I fought trolls, I climbed mountains, I even found what I believed to be the fabled well of youth![/color]"
                            A small pause.
                            A smirk forms on Seki's face.
                            He winks at you.
                            "[color=brown]Turns out it was just an ordinary river spring, but you probably could have guessed that by taking a look at me, eh?[/color]"
                        [/p]
                        [p]
                            The old man bursts into laughter, which quickly devolves into a coughing fit.
                            The smile is wiped off his face.
                            Hacking and wheezing, he spits a distinctly red-colored wad of phlegm from his beak onto the ground.
                            You fear for his well-being, the bird visibly hurting, but the moment he catches his breath,
                            he turns towards you, smile plastered across his face once more.
                            You don't know whether or not he's [i]acting[/i] tough.
                        [/p]
                        [p]
                            "[color=brown]Don't worry about me.[/color]"
                            Seki says, as if that's supposed to comfort you.
                            "[color=brown]Just a common cold.
                            Nothin' more.[/color]"
                            You mention that he has the [b]cure[/b] for that.
                            He once made you feel [b]much[/b] better with just a small potion.
                            The owl looks away.
                            All playfulness vanishes from his face, a disconcerting seriousness taking its place.
                            Tears form at the corners of his eyes.
                            He swallows deeply.
                            "[color=brown]It's not the kind of cold that can be cured.[/color]"
                        [/p]
                        [p]
                            The old man pokes a feathery finger underneath his glasses to wipe his eyes, in order to pretend he wasn't crying.
                            He turns towards you once more, a shaky, obviously faked grin on his face.
                            With the same finger he used to collect his tears, he points towards the empty coinpurse hanging from your neck.
                            "[color=brown]Well, you won't be buyin' much with that.
                            And you know the rule: no buyin' means no sellin'.[/color]"
                        [/p]
                        [p]
                            You're still stuck trying to process what he just said.
                            Is Seki going to...die?
                            The old man notices your confusion, and in an attempt to break the grim mood that has fallen upon the conversation,
                            he opens up a drawer, and fetches a familiarly shaped piece of metal.
                        [/p]
                        [p]
                            "[color=brown]Can't send you off without a means to fill up that empty pouch of yours, now can I?[/color]"
                            He asks, rhetorically, whilst handing you a single ${global.kobold.inventory.createItemWithTooltip(new Lockpick())}.
                            "[color=brown]Don't go using it all in one place now, eh?[/color]"
                            The bird jokes, seemingly [i]wanting[/i] to laugh, but not wanting to cough up another piece of his lungs.
                        [/p]
                        [p]
                            "[color=brown]Anyway, off you go.[/color]"
                            He continues, turning around and beginning to walk away at a slow pace.
                            "[color=brown]I'll be in the city for the next few days, but be sure to stop by here sometime before next week, you hear?
                            I want to see my little [b]${ctrl.gender() === GenderEnum.MALE ? "man" : "woman"}[/b] one last time before...[/color]"
                            Stopping mid-sentence, Seki lets out a loud, depressed sigh before silently disappearing into the darkness,
                            either to tend to his wounds, or to lament in solitude.
                        [/p]
                        [p]
                            Heartbroken, you hang your head and barely refrain from crying as you walk out of the old owl's shop.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.free.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.free.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiFree";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.entrance.continued() || ctrl.gold() >= ctrl.minBuyGold) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.free.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.entrance.continued() || ctrl.gold() >= ctrl.minBuyGold) {
            return;
        }

        next.registerListeners();

        if (ctrl.free.continued()) {
            return;
        }

        registerContinueListener();
    };
}
