/**
 * Arrival section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveSurface(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.arrival;
    var subController = ctrl.surface;
    var changeController = ctrl.surface;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new UndergroundCaveRun(ctrl);
    var secondNext = new UndergroundCaveAvert(ctrl);
    var thirdNext = new UndergroundCaveStare(ctrl);

    var firstChoice = UndergroundCaveSurfaceChoice.SWIM;
    var secondChoice = UndergroundCaveSurfaceChoice.AVERT;
    var thirdChoice = UndergroundCaveSurfaceChoice.STARE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With a throbbing head, and still-hurting lungs, you wearily awaken from your unpleasant slumber.
                            Your heavy eyelids are slow to open, the cave's dim lighting luckily not [i]too[/i] taxing on your semi-functional brain.
                            You don't know how long you were out for.
                            Heck, you can't even remember getting out of the flooded tunnel.
                            For a few minutes, you lie motionlessly, your mind and body both still recovering from the near-death experience.
                        [/p]
                        [p]
                            While your oxygen intake is steady, every breath you take causes serious chestpains.
                            You feel like you've ingested a box of rusty nails down your windpipe,
                            your respiratory system sore from the back of your throat to the depths of your lungs.
                            Your entire body aches, having been pushed to its very limits and beyond.
                            By all accounts, you should have been long dead,
                            yet through some miraculous combination of luck and determination,
                            or perhaps some kind of divine intervention, you have managed to make it out alive.
                        [/p]
                        [p]
                            You sigh loudly.
                            [b]Everything[/b] hurts.
                            All the oxygen deprivation has taken a hefty toll on your body, not to mention the physical strain.
                            You don't think you can stand up just yet.
                            But you can't keep lying here, either.
                            At the very least, you need to figure out where you are.
                        [/p]
                        [p]
                            You slowly get onto your unsteady hands and knees, and begin to look around.
                            You are definitely in a [i]cave[/i] of some sorts.
                            There's some faint traces of natural light, so there must be an exit somewhere.
                            The body of water you crawled out of stretches along the entire length of the cavern.
                            Must be an offshoot of the river, which means it [i]might[/i] lead back to the outside world.
                        [/p]
                        [p]
                            Besides the water, there isn't much to see.
                            A few holes line the cavern's walls, most of them too tiny -- or too [i]scary[/i] -- for you to squeeze into.
                            You figure they're tunnels, like the one you crawled in through, although yours was [i]submerged[/i].
                            Not that [i]adventure[/i] is on your mind after nearly [b]dying[/b].
                        [/p]
                        [p]
                            While tracing the walls of the cave looking for any [i]danger[/i], your eyes suddenly fall upon a pair of strange, twinkling, sparkling things.
                            Two green lights in the dark depths of one of the many holes.
                            Like wicked braziers in a sea of blackness.
                            They captivate you, their inherent beauty alluring you to stare mindlessly at them.
                            What could they be?
                            Wet, green stones?
                            Emeralds?
                            Jade crystals?
                        [/p]
                        [p]
                            Suddenly, the lights fade.
                            They flicker, if only for half a second.
                            Then you realize.
                            They're not gemstones or rocks.
                            They're [b]eyes[/b].
                            Something is staring at you from the darkness.
                            And it just blinked.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Swim away</button>`;

        var tooltip = global.parser.parse(`You can probably swim faster than you can run in the dark.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Look away</button>`;

        var tooltip = global.parser.parse(`Whatever this thing is, you don't trust its beady eyes.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Stare</button>`;

        var tooltip = global.parser.parse(`If a staring contest is what this thing wants, you're going to give it one!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.show("scenes/HamletDay2/UndergroundCave/img/eyes.gif");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var UndergroundCaveSurfaceChoice = {
    SWIM: 1,
    AVERT: 2,
    STARE: 3
};
