/**
 * Stare section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveRelent(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveStareChoice.RELENT;
    var reqController = ctrl.stare;
    var subController = ctrl.relent;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new UndergroundCaveHate(ctrl);
    var secondNext = new UndergroundCaveEnjoy(ctrl);

    var firstChoice = UndergroundCaveRelentChoice.HATE;
    var secondChoice = UndergroundCaveRelentChoice.ENJOY;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskFucked = true;
        var toReturn = `[p]
                            It's hopeless.
                            You gazed at the basilisk's eyes like an [b]idiot[/b], playing right into its cards.
                            Now most of your body has turned to stone, and you're left completely [b]defenceless[/b].
                            You are at the mercy of the hulking crocodillian, which slowly approaches you from the front.
                        [/p]
                        [p]
                            The creature draws near, crawling over the ground like the reptile it resembles.
                            Once close enough, it raises its upper body off of the ground,
                            positioning its toothy maw mere inches from your petrified muzzle.
                            You'd be able to feel its warm breath on your scales, were they not turned to numb stone.
                            The basilisk flicks out its forked tongue, licking your rock-like snout.
                            Perhaps [i]testing[/i] if you're properly turned to stone or just [i]faking it[/i]?
                        [/p]
                        [p]
                            The monster stares deeply into your eyes, but you don't return its inquisitive, probing leer.
                            While it's too late now, you've learned [b]not[/b] to peer into a basilisk's eyes, no matter how alluring.
                            Instead, you nervously look away, first to the side, then to the top of the cavern, and finally to the creature's underside.
                            Your sight wandering around the bottom end of the crocodillian's body, you realize that it's definitely [b]male[/b].
                            Its girthy, ridged and draconic-looking member hangs fully erect below its soft underbelly.
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            After the solemn tongue-flick, the beast lowers its head once more,
                            and begins to crawl around you, towards your backside.
                            Its intentions are [b]very[/b] clear, even to a dumb kobold like yourself.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Hate it</button>`;

        var tooltip = global.parser.parse(`Why the [b]hell[/b] would you enjoy getting fucked by a [b]wild beast[/b]?!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Love it</button>`;

        var tooltip = global.parser.parse(`Its member looked [i]exotic[/i]. This might end up being [b]fun[/b].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var UndergroundCaveRelentChoice = {
    HATE: 1,
    ENJOY: 2
};
