/**
 * Stare section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveResistFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.relent;
    var changeController = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveHate(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            [b]No![/b]
                            You can't let this happen!
                            You may have stared into the basilisk's eyes like an [b]idiot[/b], playing right into its cards, but this fight is [b]not[/b] over yet!
                            You begin to focus all of your willpower, all of your energy, [b]everything[/b] you've got on [b]moving[/b] your limbs.
                        [/p]
                        [p]
                            Your hand.
                            That first.
                            If you can move your hand, then you can move [b]anything[/b].
                            You close your eyes.
                            You take deep breaths through your nose.
                            You try to find some inner peace, not an easy task with a huge feral beast drawing near,
                            every scrape of its sharp claws over the stone cavern floor interrupting your meditation.
                            [b]Move, damnit![/b]
                        [/p]
                        [p]
                            You try and you try, but your hand remains frozen in place.
                            You can move your fingers, but your palm budges not even an inch.
                            Losing faith, you open your eyes again, only to be greeted by the basilisk's toothy maw, mere inches from your petrified muzzle.
                            You'd be able to feel its warm breath on your scales, were they not turned to numb stone.
                            The creature flicks out its forked tongue, licking your rock-like snout.
                            Perhaps [i]testing[/i] if you're properly turned to stone or just [i]faking it[/i]?
                        [/p]
                        [p]
                            It's too late.
                            Even [b]if[/b] you managed to regain your motion somehow,
                            the beast would probably [b]get startled[/b] and [b]lash out[/b] if you suddenly rose to your feet.
                        [/p]
                        [p]
                            The monster stares deeply into your eyes, but you don't return its inquisitive, probing leer.
                            You've learned [b]not[/b] to peer into a basilisk's eyes, no matter how alluring.
                            Instead, you nervously look away, first to the side, then to the top of the cavern, and finally to the creature's underside.
                            Your sight wandering around the bottom end of the crocodillian's body, you realize that it's definitely [b]male[/b].
                            Its girthy, ridged and draconic-looking member hangs fully erect below its soft underbelly.
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            After the solemn tongue-flick, the beast lowers its head once more,
                            and begins to crawl around you, towards your backside.
                            Its intentions are [b]very[/b] clear, even to a dumb kobold like yourself.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(UndergroundCaveRelentChoice.HATE)
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
