/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoAlleyStayContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var underwear = ctrl.misc.underwear();
        var pants = ctrl.misc.pants();
        var shirt = ctrl.misc.shirt();
        var clothing = underwear || pants || shirt;
        var toReturn = `[p]
                            As soon as the man has left the alleyway, you rise out of the puddle of pee.
                            Tears flow liberally from your eyes.
                            You feel [b]unclean[/b], [b]defiled[/b] from head to toe.
                            You wipe your face as best you can, but even dry, your scales seem [b]filthy[/b].
                            There's a horrid [b]stench[/b] lingering about, a revolting fragrance so intense you fear it may seep into your very skin.
                        [/p]
                        [p]
                            You clean off your arms, your legs and your tail as best you can.
                            Luckily, the digusting yellow fluid rolls easily off your scales, dripping down to the ground.
                            While warm at first, the liquid is quickly starting to cool down, leaving you chilly and cold ontop of being absolutely [b]revolted[/b].
                            Despite cleaning your body as best as you can, the sleazy, unsanitary feeling remains.
                            ${clothing ? `Your clothes are tainted.
                            You don't want to take them off in the middle of town.
                            They'll just have to dry on their own.` : ""}
                        [/p]
                        [p]
                            While completely disheartened, reduced to a sobbing mess of a piss-stained lizard,
                            you are glad that you escaped that encounter relatively unharmed.
                            After a few solid minutes of bawling your eyes out, you wipe your tears, and stumble towards the alleyway's entrance.
                            The man are nowhere around to be seen.
                            Having traded your dignity for your life, you start walking back towards the town square.
                        [/p]
                        [p]
                            While, at first, you curse the cool morning wind that picks up,
                            you soon learn to appreciate it for washing the stench of piss off of you,
                            and for somewhat helping to dry your ${clothing ? `clothes` : `body`}.
                            As you begin to near your destination, you notice the sun slowly rising above the rooftops.
                            You must have lost track of time while exploring the city.
                            Or maybe you were left crying in the alleyway for a longer period than you care to remember.
                            Either way, you guess you won't be sleeping tonight.
                        [/p]
                        [p]
                            The twinkle of magic you felt at midnight has all but faded, giving way to a sense of [b]vulnerability[/b].
                            You are but a lone, weak, small, kobold in a big city filled with people who can and [b]want[/b] to maim,
                            hurt, kill and perhaps even [b]rape[/b] you.
                            If you let your guard down for even one moment, it could cost you your money, your life or both.
                            You'd worry about losing your pride, but you fear you have little of that left as it is.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.alleyStay.continued()) {
            return "";
        }

        global.ui.applyTheme("varanar_morning");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.endChange.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.alleyStay.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
